@@ -23,7 +23,9 @@ def get():
         'gladedir':      os.path.join('/usr/local/share', 'istanbul', 'glade'),
         'imagedir':      os.path.join('/usr/local/share', 'istanbul', 'image'),
         'pythondir':     os.path.join('/usr/local/lib', 'istanbul', 'python'),
-        'version':       '0.1.1'
+        'localedir':     os.path.join('/usr/local/share', 'locale'),
+        'domain':       'istanbul',
+        'version':       '0.2.1'
     }
 
 config_dict = get()
